
# Slot: doc


Description of corresponding object.

URI: [nwb_schema_language:Schema_doc](https://w3id.org/p2p_ld/nwb-schema-language/Schema_doc)


## Domain and Range

[Schema](Schema.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents

 *  is_a: [doc](doc.md)

## Children


## Used by

 * [Schema](Schema.md)
